<?php

namespace DTInternet\DtiOnlineconsulting\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2022 Stefan Bublies <bublies@dt-internet.de>
 *
 *  All rights reserved
 *
 ***************************************************************/

use \TYPO3\CMS\Core\Utility\GeneralUtility;
use \TYPO3\CMS\Extbase\Mvc\Controller\ActionController;
use DTInternet\DtiUsermanagement\Utility\FeuserUtility;
use DTInternet\DtiOnlineconsulting\Utility\LivechatApiUtility;
use TYPO3\CMS\Extbase\Domain\Repository\FrontendUserRepository;

/**
 * (c) 2022 Stefan Bublies bublies@dt-internet.de
 */
class LivechatController extends ActionController
{

    /**
     * @var \TYPO3\CMS\Extbase\Persistence\Generic\PersistenceManager
     * @TYPO3\CMS\Extbase\Annotation\Inject
     */
    protected $persistenceManager;

    /**
     * Init the persistenceManager
     *
     * @return void
     */
    public function __construct()
    {
        $this->persistenceManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance("TYPO3\\CMS\\Extbase\\Persistence\\Generic\\PersistenceManager");
    }

    /**
     * livechatRepository
     *
     * @var \DTInternet\DtiOnlineconsulting\Domain\Repository\LivechatRepository
     */
    protected $livechatRepository = null;

    /**
     * @param \DTInternet\DtiOnlineconsulting\Domain\Repository\LivechatRepository $livechatRepository
     */
    public function injectLivechatRepository(\DTInternet\DtiOnlineconsulting\Domain\Repository\LivechatRepository $livechatRepository)
    {
        $this->livechatRepository = $livechatRepository;
    }

    /**
     * @return void
     */
    public function agentsAction()
    {
        $feUserData = FeuserUtility::get();

        if($feUserData['usergroup'] == 1) { // muss noch per Konstante variabel gemacht werden
            $chatSession = $this->livechatRepository->findByAgent($feUserData['uid'])->getFirst();
            $activeChat = LivechatApiUtility::checkAgent($feUserData['uid']);
            if ($chatSession > 0 && $activeChat == TRUE) {

                // Token generieren fuer den Live-Chat
                $token = $this->gen_Token($chatSession->getChatid(),$feUserData['username'],$feUserData['uid'], 1);

                // URL to Chat-API
                $uri = 'https://conf.drkduisburg.apps.hosting/chat/drk-duisburg/connect?token='.$token; // Identifier noch flexibel machen
                $this->view->assignMultiple([
                    'agentChatUrl' => $uri,
                    'agent' => 1,
                    'activeChats' => 1,
                ]);
            } else {
                $this->view->assignMultiple([
                    'activeChats' => 0,
                    'agent' => 1
                ]);
            }

        } else {
            $agentIDs = explode(',', $this->settings['agents']);
            $agents = FeuserUtility::readFeUserData($agentIDs);
            $agentsSession = FeuserUtility::validateAgentsSession();

            $activeChats = LivechatApiUtility::checkAgents();

            $this->view->assignMultiple([
                'feusers' => $agents,
                'agentssession' => $agentsSession,
                'activeChats' => $activeChats
            ]);
        }
    }

    /**
     *
     * @return void
     */
    public function generateLivechatAction()
    {
        $arguments = $this->request->getArguments();
        $agent = FeuserUtility::readFeUserDataSingle($arguments['agent']);
        $feUserData = FeuserUtility::get();

        // Store in Database
        $chatId = $this->gen_chatId();
        if($feUserData['usergroup'] > 1) { // muss noch per Konstante variabel gemacht werden
            $newRequest = new \DTInternet\DtiOnlineconsulting\Domain\Model\Livechat();
            $newRequest->setChatid($chatId);
            $newRequest->setPid(17); // muss noch per Konstante variabel gemacht werden
            $newRequest->setFeuser($feUserData['uid']);
            $newRequest->setAgent($agent->getUid());
        }

        $this->livechatRepository->add($newRequest);
        $this->persistenceManager->persistAll();

        // Token generieren fuer den Live-Chat
        $token = $this->gen_Token($chatId,$feUserData['username'],$agent->getUid(), 0);

        // Redirect to Chat-API
        $uri = 'https://conf.drkduisburg.apps.hosting/chat/drk-duisburg/connect?token='.$token;
        $this->redirectToURI($uri, $delay = 0, $statusCode = 303);

    }

    /**
     * @return string
     */
    public function gen_chatId() {
        return sprintf( '%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
            // 32 bits for "time_low"
            mt_rand( 0, 0xffff ), mt_rand( 0, 0xffff ),

            // 16 bits for "time_mid"
            mt_rand( 0, 0xffff ),

            // 16 bits for "time_hi_and_version",
            // four most significant bits holds version number 4
            mt_rand( 0, 0x0fff ) | 0x4000,

            // 16 bits, 8 bits for "clk_seq_hi_res",
            // 8 bits for "clk_seq_low",
            // two most significant bits holds zero and one for variant DCE1.1
            mt_rand( 0, 0x3fff ) | 0x8000,

            // 48 bits for "node"
            mt_rand( 0, 0xffff ), mt_rand( 0, 0xffff ), mt_rand( 0, 0xffff )
        );
    }

    /**
     * @param $username
     * @param $agentUid
     * @param $roomId
     * @param $isagent
     * @return string
     * @throws \Exception
     */
    public function gen_Token($roomId, $username, $agentUid, $isagent)
    {
        if ($isagent == 1) {
            $uidSupporter = $agentUid;
        } else {
            $uidSupporter = $agentUid;
        }
        $tokenheader = json_encode(['typ' => 'JWT', 'alg' => 'HS256']);
        $tokenpayload = json_encode(['roomId' => $roomId, 'pseudonym' => $username, 'uidSupporter' => $uidSupporter]);
        $tokenbase64UrlHeader = str_replace(['+', '/', '='], ['-', '_', ''], base64_encode($tokenheader));
        $tokenbase64UrlPayload = str_replace(['+', '/', '='], ['-', '_', ''], base64_encode($tokenpayload));
        $tokensignature = hash_hmac('sha256', $tokenbase64UrlHeader . "." . $tokenbase64UrlPayload, '2WMf3boMpA9mjDuKdXIkNd07PvXLrwPRSdfCG9MfNz6qp3YbjzTLSzdho5zdSAGo', true);
        $tokenbase64UrlSignature = str_replace(['+', '/', '='], ['-', '_', ''], base64_encode($tokensignature));
        $token = $tokenbase64UrlHeader . "." . $tokenbase64UrlPayload . "." . $tokenbase64UrlSignature;

        return $token;
    }
}
