<?php

namespace DTInternet\DtiOnlineconsulting\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2022 Stefan Bublies <bublies@dt-internet.de>
 *
 *  All rights reserved
 *
 ***************************************************************/

use \TYPO3\CMS\Core\Utility\GeneralUtility;
use \TYPO3\CMS\Extbase\Mvc\Controller\ActionController;
use DTInternet\DtiUsermanagement\Utility\FeuserUtility;
use TYPO3\CMS\Extbase\Domain\Repository\FrontendUserRepository;
use TYPO3\CMS\Extbase\Utility\LocalizationUtility as Locallang;
use \Datetime;

/**
 * (c) 2022 Stefan Bublies bublies@dt-internet.de
 */
class VideomeetController extends ActionController
{


    /**
     * @var \TYPO3\CMS\Extbase\Persistence\Generic\PersistenceManager
     * @TYPO3\CMS\Extbase\Annotation\Inject
     */
    protected $persistenceManager;

    /**
     * Init the persistenceManager
     *
     * @return void
     */
    public function __construct()
    {
        $this->persistenceManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance("TYPO3\\CMS\\Extbase\\Persistence\\Generic\\PersistenceManager");
    }

    /**
     * videoconsultingRepository
     *
     * @var \DTInternet\DtiOnlineconsulting\Domain\Repository\VideoconsultingRepository
     */
    protected $videoconsultingRepository = null;

    /**
     * @param \DTInternet\DtiOnlineconsulting\Domain\Repository\VideoconsultingRepository $videoconsultingRepository
     */
    public function injectVideoconsultingRepository(\DTInternet\DtiOnlineconsulting\Domain\Repository\VideoconsultingRepository $videoconsultingRepository)
    {
        $this->videoconsultingRepository = $videoconsultingRepository;
    }

    /**
     * @return void
     */
    public function videorequestAction()
    {

        $arguments = $this->request->getArguments();
        $feUserData = FeuserUtility::get();

        // Store in Database
        if ($arguments['videmeetrequest']) {
            $videoId = $this->gen_videoId();
            $password = substr($videoId, 25, -1);
            if($feUserData['usergroup'] > 1) { // muss noch per Konstante variabel gemacht werden
                $newRequest = new \DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting();
                $newRequest->setVideoid($videoId);
                $newRequest->setPid(17); // muss noch per Konstante variabel gemacht werden
                $newRequest->setFeuser($feUserData['uid']);
                $newRequest->setAgent(0);
                $newRequest->setPreferreddate(new DateTime($arguments['videmeetrequest']['preferreddate']));
                $newRequest->setInformation($arguments['videmeetrequest']['information']);
                $newRequest->setPassword($password);
            }

            $this->videoconsultingRepository->add($newRequest);
            $this->persistenceManager->persistAll();

            $this->addFlashMessage(
                Locallang::translate('tx_dtionlineconsulting.videomeet.success.body', 'dti_onlineconsulting', NULL),
                Locallang::translate('tx_dtionlineconsulting.videomeet.success.header', 'dti_onlineconsulting', NULL),
                \TYPO3\CMS\Core\Messaging\AbstractMessage::OK
            );
            $this->view->assignMultiple(['password' => $password]);

        } else {
            $this->view->assignMultiple(['feuser' => $feUserData, 'newRequest' => 1, 'openVideoDates' => $this->videoconsultingRepository->findByFeuser($feUserData['uid'])]);
        }

    }

    /**
     * @param \DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting $videoconsulting
     * @return void
     */
    public function showAction(\DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting $videoconsulting)
    {
        $this->view->assignMultiple(['date' => $videoconsulting]);
    }


    /**
     * @return string
     */
    public function gen_videoId() {
        return sprintf( '%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
            // 32 bits for "time_low"
            mt_rand( 0, 0xffff ), mt_rand( 0, 0xffff ),

            // 16 bits for "time_mid"
            mt_rand( 0, 0xffff ),

            // 16 bits for "time_hi_and_version",
            // four most significant bits holds version number 4
            mt_rand( 0, 0x0fff ) | 0x4000,

            // 16 bits, 8 bits for "clk_seq_hi_res",
            // 8 bits for "clk_seq_low",
            // two most significant bits holds zero and one for variant DCE1.1
            mt_rand( 0, 0x3fff ) | 0x8000,

            // 48 bits for "node"
            mt_rand( 0, 0xffff ), mt_rand( 0, 0xffff ), mt_rand( 0, 0xffff )
        );
    }

}
