<?php

namespace DTInternet\DtiUsermanagement\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2022 Stefan Bublies <bublies@dt-internet.de>
 *
 *  All rights reserved
 *
 ***************************************************************/

use \TYPO3\CMS\Core\Utility\GeneralUtility;
use \TYPO3\CMS\Extbase\Mvc\Controller\ActionController;
use DTInternet\DtiUsermanagement\Utility\FeuserUtility;
use TYPO3\CMS\Extbase\Utility\LocalizationUtility as Locallang;

/**
 * (c) 2022 Stefan Bublies bublies@dt-internet.de
 */
class RegisterController extends ActionController
{
    public function registerAction()
    {
        $arguments = $this->request->getArguments();
        if (!is_null($arguments['usermanagement'])) {
            $validateFeUser = FeuserUtility::validateAndStoreFeUserData($arguments['usermanagement']);
            if (!is_null($validateFeUser) && is_array($validateFeUser)) {
                if ($validateFeUser[0]['deleted'] == 1 || $validateFeUser[0]['disable'] == 1) {
                    $usernameIsFreeDate = date('d.m.Y', strtotime("+48 hours", $validateFeUser[0]['deletedate']));
                    $this->addFlashMessage(
                        Locallang::translate('tx_dtiusermanagement.messages.useraccount.error1.body', 'dti_usermanagement', array($usernameIsFreeDate)),
                        Locallang::translate('tx_dtiusermanagement.messages.useraccount.error1.header', 'dti_usermanagement', NULL),
                        \TYPO3\CMS\Core\Messaging\AbstractMessage::ERROR
                    );
                } else {
                    $this->addFlashMessage(
                        Locallang::translate('tx_dtiusermanagement.messages.useraccount.error2.body', 'dti_usermanagement', NULL),
                        Locallang::translate('tx_dtiusermanagement.messages.useraccount.error2.header', 'dti_usermanagement', NULL),
                        \TYPO3\CMS\Core\Messaging\AbstractMessage::ERROR
                    );
                }
                $this->view->assign('registerData', $arguments['usermanagement']);
            } else {
                $this->addFlashMessage(
                    Locallang::translate('tx_dtiusermanagement.messages.useraccount.success.body', 'dti_usermanagement', NULL),
                    Locallang::translate('tx_dtiusermanagement.messages.useraccount.success.header', 'dti_usermanagement', NULL),
                    \TYPO3\CMS\Core\Messaging\AbstractMessage::OK
                );
                $this->view->assign('registerSucces', 1);
            }
        }
    }

    /**
     * (c) 2022 Stefan Bublies bublies@dt-internet.de
     */
    public function updateAction()
    {
        $arguments = $this->request->getArguments();

        $getParameters = \TYPO3\CMS\Core\Utility\GeneralUtility::_GET();
        $isItLogoutAndDelete = $getParameters['logout'];

        if($getParameters['logout'] == 1) {
            $this->view->assign('logoutAndDelete',$getParameters['logout']);
            $this->view->assign('settings', $this->settings);
        } else {
            $this->view->assign('logoutAndDelete',2);
            $this->view->assign('settings', $this->settings);
        }

        if (!is_null($arguments['usermanagement'])) {
            FeuserUtility::updateUser($arguments['usermanagement']);
            $this->addFlashMessage(
                Locallang::translate('tx_dtiusermanagement.messages.useraccount.update.success.body', 'dti_usermanagement', NULL),
                Locallang::translate('tx_dtiusermanagement.messages.useraccount.update.success.header', 'dti_usermanagement', NULL),
                \TYPO3\CMS\Core\Messaging\AbstractMessage::OK
            );
            $feUserData = FeuserUtility::get();
            $this->view->assign('registerData',$feUserData);
            $uriBuilder = $this->controllerContext->getUriBuilder();
            $uri = $uriBuilder
                ->reset()
                ->uriFor('update', array(), 'Register', 'DtiUsermanagement', 'Usermanagement');
            $this->redirectToURI($uri, 0, 301);


        } else {
            $feUserData = FeuserUtility::get();
            $this->view->assign('registerData',$feUserData);
        }

    }

    /**
     * @return void
     */
    public function deleteAction()
    {
        $arguments = $this->request->getArguments();
        FeuserUtility::deleteUser($arguments['user']);
        \dti\typo3::FeUser()->logout();
        $uriBuilder = $this->controllerContext->getUriBuilder();
        $uriBuilder->setTargetPageUid(1); // noch per TypoScript konfiguriertbar machen
        $uriBuilder->setArguments(array('logout' => 1));
        $uri = $uriBuilder->build();
        $this->redirectToURI($uri, 0, 301);

    }

    /**
     * @return void
     */
    public function agentstateAction()
    {
        $arguments = $this->request->getArguments();
        $feUserData = FeuserUtility::get();
        $this->view->assignMultiple([
            'feuserData' => $feUserData,
            'formData' => $arguments['agentstate']
        ]);
        if (!is_null($arguments['agentstate'])) {
            FeuserUtility::updateState($feUserData, $arguments['agentstate']);
            $this->addFlashMessage(
                Locallang::translate('tx_dtiusermanagement.messages.agentstate.success.body', 'dti_usermanagement', NULL),
                Locallang::translate('tx_dtiusermanagement.messages.agentstate.success.header', 'dti_usermanagement', NULL),
                \TYPO3\CMS\Core\Messaging\AbstractMessage::OK
            );
        }
    }
}
