<?php
declare(strict_types=1);
namespace DTInternet\DtiUsermanagement\Domain\Model\Dto;

/*
 * This file is part of the Extension "dti_usermanagement" for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 */

/**
 * Class User
 */
class User extends \TYPO3\CMS\Extbase\Domain\Model\FrontendUser
{
    /**
     * security question
     *
     * @var string
     */
    protected $secretkey = '';

    /**
     * is consulting client
     *
     * @var bool
     */
    protected $known = false;

    /**
     * is online
     *
     * @var bool
     */
    protected $isonline = false;

    /**
     * available for live chat
     *
     * @var bool
     */
    protected $chatavailable = false;

    /**
     * Questions
     *
     * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Topics>
     */
    protected $topics = null;

    /**
     * videoconsulting
     *
     * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting>
     */
    protected $videoconsulting = null;

    /**
     * consulting categories
     *
     * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Categories>
     */
    protected $categories = null;

    /**
     * delete time
     *
     * @var \DateTime
     */
    protected $deletedate = null;


    /**
     * @return string
     */
    public function getSecretkey(): string
    {
        return $this->secretkey;
    }

    /**
     * @param string $secretkey
     */
    public function setSecretkey(string $secretkey)
    {
        $this->secretkey = $secretkey;
    }

    /**
     * Returns the known
     *
     * @return bool $known
     */
    public function getKnown()
    {
        return $this->known;
    }

    /**
     * Sets the known
     *
     * @param bool $known
     * @return void
     */
    public function setKnown($known)
    {
        $this->known = $known;
    }

    /**
     * Returns the boolean state of known
     *
     * @return bool
     */
    public function isKnown()
    {
        return $this->known;
    }

    /**
     * Adds a topics
     *
     * @param \DTInternet\DtiOnlineconsulting\Domain\Model\Topics $topics
     * @return void
     */
    public function addTopics(\DTInternet\DtiOnlineconsulting\Domain\Model\Topics $topics)
    {
        $this->topics->attach($topics);
    }

    /**
     * Removes a topics
     *
     * @param \DTInternet\DtiOnlineconsulting\Domain\Model\Topics $topicsToRemove The Dates to be removed
     * @return void
     */
    public function removeTopics(\DTInternet\DtiOnlineconsulting\Domain\Model\Topics $topicsToRemove)
    {
        $this->topics->detach($topicsToRemove);
    }

    /**
     * Returns the topics
     *
     * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Topics> $topics
     */
    public function getTopics()
    {
        return $this->topics;
    }

    /**
     * Sets the topics
     *
     * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Topics> $topics
     * @return void
     */
    public function setTopics(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $topics)
    {
        $this->topics = $topics;
    }

    /**
     * Adds a videoconsulting
     *
     * @param \DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting $videoconsulting
     * @return void
     */
    public function addVideoconsulting(\DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting $videoconsulting)
    {
        $this->videoconsulting->attach($videoconsulting);
    }

    /**
     * Removes a videoconsulting
     *
     * @param \DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting $videoconsultingToRemove The Dates to be removed
     * @return void
     */
    public function removeVideoconsulting(\DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting $videoconsultingToRemove)
    {
        $this->videoconsulting->detach($videoconsultingToRemove);
    }

    /**
     * Returns the videoconsulting
     *
     * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting> $videoconsulting
     */
    public function getVideoconsulting()
    {
        return $this->videoconsulting;
    }

    /**
     * Sets the videoconsulting
     *
     * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Videoconsulting> $videoconsulting
     * @return void
     */
    public function setVideoconsulting(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $videoconsulting)
    {
        $this->videoconsulting = $videoconsulting;
    }

    /**
     * Adds a categories
     *
     * @param \DTInternet\DtiOnlineconsulting\Domain\Model\Categories $categories
     * @return void
     */
    public function addCategories(\DTInternet\DtiOnlineconsulting\Domain\Model\Categories $categories)
    {
        $this->categories->attach($categories);
    }

    /**
     * Removes a categories
     *
     * @param \DTInternet\DtiOnlineconsulting\Domain\Model\Categories $categoriesToRemove The Dates to be removed
     * @return void
     */
    public function removeCategories(\DTInternet\DtiOnlineconsulting\Domain\Model\Categories $categoriesToRemove)
    {
        $this->categories->detach($categoriesToRemove);
    }

    /**
     * Returns the categories
     *
     * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Categories> $categories
     */
    public function getCategories()
    {
        return $this->categories;
    }

    /**
     * Sets the categories
     *
     * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\DTInternet\DtiOnlineconsulting\Domain\Model\Categories> $categories
     * @return void
     */
    public function setCategories(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $categories)
    {
        $this->categories = $categories;
    }

    /**
     * Returns the deletedate
     *
     * @return \DateTime $deletedate
     */
    public function getDeletedate()
    {
        return $this->deletedate;
    }

    /**
     * Sets the deletedate
     *
     * @param \DateTime $deletedate
     * @return void
     */
    public function setDeletedate(\DateTime $deletedate)
    {
        $this->deletedate = $deletedate;
    }

    /**
     * Returns the isonline
     *
     * @return bool $isonline
     */
    public function getIsonline()
    {
        return $this->isonline;
    }

    /**
     * Sets the isonline
     *
     * @param bool $isonline
     * @return void
     */
    public function setIsonline($isonline)
    {
        $this->isonline = $isonline;
    }

    /**
     * Returns the boolean state of isonline
     *
     * @return bool
     */
    public function isIsonline()
    {
        return $this->isonline;
    }

    /**
     * Returns the chatavailable
     *
     * @return bool $chatavailable
     */
    public function getChatavailable()
    {
        return $this->chatavailable;
    }

    /**
     * Sets the chatavailable
     *
     * @param bool $chatavailable
     * @return void
     */
    public function setChatavailable($chatavailable)
    {
        $this->chatavailable = $chatavailable;
    }

    /**
     * Returns the boolean state of chatavailable
     *
     * @return bool
     */
    public function isChatavailable()
    {
        return $this->chatavailable;
    }

}
